@@ -15,10 +15,11 @@
 """
 import sys
 import warnings
+
 import zope.proxy
 
 
-class Deferred(object):
+class Deferred:
 
     def __init__(self, name, specifier):
         self.__name__ = name
@@ -40,10 +41,11 @@ class Deferred(object):
                 v = getattr(v, n)
         return v
 
+
 class DeferredAndDeprecated(Deferred):
 
     def __init__(self, name, specifier, message):
-        super(DeferredAndDeprecated, self).__init__(name, specifier)
+        super().__init__(name, specifier)
         self.message = message
 
     def get(self):
@@ -51,25 +53,31 @@ class DeferredAndDeprecated(Deferred):
             self.__name__ + " is deprecated. " + self.message,
             DeprecationWarning, stacklevel=3)
 
-        return super(DeferredAndDeprecated, self).get()
+        return super().get()
 
 
 class ModuleProxy(zope.proxy.ProxyBase):
-    __slots__ = ('__deferred_definitions__', )
+    __slots__ = ('__deferred_definitions__', '__doc__')
 
     def __init__(self, module):
-        super(ModuleProxy, self).__init__(module)
+        super().__init__(module)
         self.__deferred_definitions__ = {}
+        self.__doc__ = module.__doc__
 
     def __getattr__(self, name):
         try:
-            get = self.__deferred_definitions__.pop(name)
+            get = self.__deferred_definitions__[name]
         except KeyError:
             raise AttributeError(name)
         v = get.get()
         setattr(self, name, v)
+        try:
+            del self.__deferred_definitions__[name]
+        except KeyError:  # pragma: no cover
+            pass
         return v
 
+
 def initialize(level=1):
     """Prepare a module to support deferred imports.
 
@@ -91,7 +99,7 @@ def initialize(level=1):
     """
     __name__ = sys._getframe(level).f_globals['__name__']
     module = sys.modules[__name__]
-    if not (type(module) is ModuleProxy):
+    if type(module) is not ModuleProxy:
         module = ModuleProxy(module)
         sys.modules[__name__] = module
 
@@ -99,6 +107,7 @@ def initialize(level=1):
         return
     return module
 
+
 def define(**names):
     """Define deferred imports using keyword parameters.
 
@@ -111,6 +120,7 @@ def define(**names):
     for name, specifier in names.items():
         __deferred_definitions__[name] = Deferred(name, specifier)
 
+
 def defineFrom(from_name, *names):
     """Define deferred imports from a particular module.
 
@@ -123,6 +133,7 @@ def defineFrom(from_name, *names):
         specifier = from_name + ':' + name
         __deferred_definitions__[name] = Deferred(name, specifier)
 
+
 def deprecated(message, **names):
     """Define deferred and deprecated imports using keyword parameters.
 
@@ -139,6 +150,7 @@ def deprecated(message, **names):
         __deferred_definitions__[name] = DeferredAndDeprecated(
             name, specifier, message)
 
+
 def deprecatedFrom(message, from_name, *names):
     """Define deferred and deprecated imports from a particular module.
 
